@@ -4,6 +4,7 @@ use super::*;
 const CAPACITY: usize = 16;
 
 /// Sized pool object with a max capacity of 16 items.
+#[derive(Copy, Clone)]
 pub struct SizedPool16<ItemType> { 
     items: [Option<ItemType>; CAPACITY], 
     order: [usize; CAPACITY], 
@@ -77,6 +78,14 @@ where ItemType: Copy + PartialEq
     }
 }
 
+impl<ItemType> Default for SizedPool16<ItemType> 
+where ItemType: Copy + PartialEq
+{
+    fn default() -> Self {
+        SizedPool16::<ItemType>::new()
+    }
+}
+
 impl<ItemType> StackPool<ItemType> for SizedPool16<ItemType> {
     fn count(&self) -> &usize { 
         &self.count 
